@@ -384,6 +384,20 @@ eel_g_str_list_alphabetize (GList *list)
 	return g_list_sort (list, (GCompareFunc) eel_strcoll);
 }
 
+int
+eel_g_str_list_index (GList *str_list,
+		      const char *str)
+{
+	int i;
+	GList *l;
+	for (i = 0, l = str_list; l != NULL; l = l->next, i++) {
+		if (!strcmp (str, (const char*)l->data)) {
+			return i;
+		}
+	}
+	return -1;
+}
+
 /**
  * eel_g_list_free_deep_custom
  *
